"use strict";(self["webpackChunkuniqua"]=self["webpackChunkuniqua"]||[]).push([[193],{2193:(e,t,n)=>{n.r(t),n.d(t,{default:()=>f});var l=n(3673);const s={class:"fullscreen bg-blue text-white text-center q-pa-md flex flex-center"},o=(0,l._)("div",{style:{"font-size":"30vh"}}," 404 ",-1),c=(0,l._)("div",{class:"text-h2",style:{opacity:".4"}}," Oops. Nothing here... ",-1);function a(e,t,n,a,r,u){const i=(0,l.up)("q-btn");return(0,l.wg)(),(0,l.iD)("div",s,[(0,l._)("div",null,[o,c,(0,l.Wm)(i,{class:"q-mt-xl",color:"white","text-color":"blue",unelevated:"",to:"/",label:"Go Home","no-caps":""})])])}const r=(0,l.aZ)({name:"Error404"});var u=n(4260),i=n(8240),d=n(7518),h=n.n(d);const p=(0,u.Z)(r,[["render",a]]),f=p;h()(r,"components",{QBtn:i.Z})}}]);